--[[
	Manages different states. That's all. Nothing you haven't seen before.
]]

include("state.lua");

StateManager = class();

function StateManager:constructor()
	self.stateQueue = {};
end

-- Runs the update function for the current state.
function StateManager:run()
	if( #self.stateQueue > 0 ) then
		self.stateQueue[#self.stateQueue].update();
	end
end

-- Returns the current running state (if there is one)
-- Otherwise, returns nil.
function StateManager:getState()
	if( #self.stateQueue > 0 ) then

		return self.stateQueue[#self.stateQueue];

	else
		return nil;
	end
end

-- Push a new state onto the queue. This will be the
-- state that gets run *next cycle*, not immediately.
function StateManager:pushState(newState)
	if( type(newState) == nil ) then
		error("Function expects a parameter.", 2);
	end
	if( type(newState) ~= "table" or newState:is_a(State) == false ) then
		error("Parameter is not a state object.", 2);
	end

	table.insert(self.stateQueue, newState);
end

-- Pops the top state off the queue.
function StateManager:popState()
	if( #self.stateQueue > 0 ) then
		table.remove(self.stateQueue);
	end
end